# -*- coding: utf-8 -*-
import velamentum.dateien.Datei
from velamentum.multimedia.Recorder import Recorder
from velamentum.ui.dialoge.Dialog import Dialog
from velamentum.android import *

class AudioRecorder(Recorder):
    """Die Klasse AudioRecorder dient der Aufnahme von Tondaten in eine Datei.
    
    Attribute:
        --- von 'Recorder' geerbte ---
    """

    def __init__(self, pDatei=velamentum.dateien.Datei.Datei("/sdcard/aufnahme.m4a")):
        """Konstruktor. Initialisiert den AudioRecorder.
        
        Parameter:
            [optional] datei (Datei): Datei, in der die Aufnahme gespeichert
                werden soll [Standardwert: Datei mit Pfad '/scard/aufnahme.m4a'].
        """
        Recorder.__init__(self, pDatei)
        
    def aufnehmen(self):
        """Auftrag. Startet die Aufnahme der Multimediadaten. 
        
        HINWEIS: Die angegebene Datei wird überschrieben.
        
        Parameter 
            --- keine ---
        """
        Recorder.aufnehmen(self)
        androide.recorderStartMicrophone(self.datei.nennePfad())
    
    def stoppen(self):
        """Auftrag. Stoppt die Aufnahme der Multimediadaten.
        
        Parameter 
            --- keine ---
        """
        Recorder.stoppen(self)
        androide.recorderStop()
        
    def aufnehmenInteraktiv(self):
        """Auftrag. Startet eine interaktive Aufnahme. Der Benutzer erhält die
        Möglichkeit die Aufnahme interaktiv zu starten und zu stoppen. Dazu wird
        in der Regel auf die jeweilige Recorder-Applikation zurückgegriffen.
        
        HINWEIS: Die angegebene Datei wird überschrieben.
        
        Parameter:
            --- keine ---
        """
        self.aufnehmen()
        dialog = Dialog("Audioaufnahme", "Aufnahme gestartet. Zum Beenden" \
            "'Ok' drücken.")
        dialog.zeige()
        self.stoppen()

